@@ -607,7 +607,7 @@ rb_shell_sync_state (RBShell *shell)
 	}
 	
 	rb_debug ("saving playlists");
-	rb_playlist_manager_save_playlists (shell->priv->playlist_manager);
+	rb_playlist_manager_save_playlists (shell->priv->playlist_manager, TRUE);
 
 	rb_debug ("saving db");
 	rhythmdb_read_lock (shell->priv->db);
@@ -640,7 +640,7 @@ idle_save_rhythmdb (RhythmDB *db)
 static gboolean
 idle_save_playlist_manager (RBPlaylistManager *mgr)
 {
-	rb_playlist_manager_save_playlists (mgr);
+	rb_playlist_manager_save_playlists (mgr, FALSE);
 
 	return TRUE;
 }
