@@ -255,16 +255,16 @@ rb_query_creator_constructor (GType type, guint n_construct_properties,
 	dlg->priv->limit_entry = GTK_WIDGET (glade_xml_get_widget (xml, "limitEntry"));
 	dlg->priv->limit_option = GTK_WIDGET (glade_xml_get_widget (xml, "limitOption"));
 
-	g_signal_connect (G_OBJECT (dlg->priv->limit_check), "toggled", G_CALLBACK (limit_toggled_cb),
-			  dlg);
+	g_signal_connect_object (G_OBJECT (dlg->priv->limit_check), "toggled", G_CALLBACK (limit_toggled_cb),
+				 dlg, 0);
 	gtk_widget_set_sensitive (dlg->priv->limit_entry, FALSE);
 	gtk_widget_set_sensitive (dlg->priv->limit_option, FALSE);
 
 	dlg->priv->vbox = GTK_BOX (glade_xml_get_widget (xml, "sub_vbox"));
 	dlg->priv->addbutton = gtk_button_new_from_stock (GTK_STOCK_ADD);
 	gtk_size_group_add_widget (dlg->priv->button_size_group, dlg->priv->addbutton);
-	g_signal_connect (G_OBJECT (dlg->priv->addbutton), "clicked", G_CALLBACK (add_button_click_cb),
-			  dlg);
+	g_signal_connect_object (G_OBJECT (dlg->priv->addbutton), "clicked", G_CALLBACK (add_button_click_cb),
+				 dlg, 0);
 	first_option = create_property_option_menu (dlg, property_options,
 						    G_N_ELEMENTS (property_options),
 						    FALSE);
@@ -377,7 +377,7 @@ rb_query_creator_load_query (RBQueryCreator *creator, GPtrArray *query,
 			     int limit_count, int limit_size)
 {
 	int i;
-	GList *rows = creator->priv->rows;
+	GList *rows;
 	gboolean disjunction = FALSE;
 	RhythmDBQueryData *qdata;
 	GPtrArray *subquery;
@@ -395,6 +395,8 @@ rb_query_creator_load_query (RBQueryCreator *creator, GPtrArray *query,
 			append_row (creator);
 	}
 	
+	rows = creator->priv->rows;
+
 	for (i = 0; i < subquery->len; i++) {
 		RhythmDBQueryData *data = g_ptr_array_index (subquery, i);
 		GtkOptionMenu *propmenu;
@@ -507,8 +509,8 @@ get_entry_for_property (RBQueryCreator *creator, RhythmDBPropType prop,
 		return gtk_entry_new ();
 	else if (prop == RHYTHMDB_PROP_RATING) {
 		RBRating *rating = rb_rating_new ();
-		g_signal_connect (G_OBJECT (rating), "rated",
-				  G_CALLBACK (set_rating_score), NULL);
+		g_signal_connect_object (G_OBJECT (rating), "rated",
+					 G_CALLBACK (set_rating_score), NULL, 0);
 		*constrain = FALSE;
 		return GTK_WIDGET (rating);
 	} else
@@ -699,8 +701,8 @@ append_row (RBQueryCreator *dialog)
 			      dialog->priv->addbutton);
 
 	remove_button = gtk_button_new_from_stock (GTK_STOCK_REMOVE);
-	g_signal_connect (G_OBJECT (remove_button), "clicked", G_CALLBACK (remove_button_click_cb),
-			  dialog);
+	g_signal_connect_object (G_OBJECT (remove_button), "clicked", G_CALLBACK (remove_button_click_cb),
+				 dialog, 0);
 	gtk_size_group_add_widget (dialog->priv->button_size_group, remove_button);
 	gtk_box_pack_start_defaults (last_hbox, GTK_WIDGET (remove_button));
 
@@ -836,8 +838,8 @@ setup_property_option_menu (RBQueryCreator *creator,
 
 	gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), menu);
 
-	g_signal_connect (G_OBJECT (option_menu), "changed",
-			  G_CALLBACK (property_option_menu_changed), creator);
+	g_signal_connect_object (G_OBJECT (option_menu), "changed",
+				 G_CALLBACK (property_option_menu_changed), creator, 0);
 }
 
 static void
